# Changelog

## 0.2.1 (2025-06-26)
- fixed filter implementation for classes as ColSpec columns

## 0.2.0 (2025-06-25)
- fixed multi-inheritance column specifications
- improved dataframely/colspec messup error messages

## 0.1.1 (2025-06-11)
- fixed pypi package dependencies

## 0.1.0 (2025-06-08)
Initial release.

- Mostly 1:1 copy of dataframely (including testbench)
- Support for SQL validation
- Support for Rules and Filters with pydiverse.transform syntax
